@@ -41,11 +41,12 @@ func (root *Root) draw(ctx context.Context) {
 		root.drawSectionHeader()
 	}
 
-	if root.scr.mouseSelect {
-		root.drawSelect(root.scr.x1, root.scr.y1, root.scr.x2, root.scr.y2, true)
+	if root.scr.mouseSelect != SelectNone {
+		root.drawSelect(root.scr.x1, root.scr.y1, root.scr.x2, root.scr.y2, root.scr.mouseSelect)
 	}
 
 	root.drawStatus()
+	root.drawTitle()
 	root.Screen.Show()
 }
 
@@ -223,6 +224,9 @@ func (root *Root) drawWrapLine(y int, lX int, lN int, lineC LineC) (int, int) {
 			break
 		}
 		screen.SetContent(x, y, c.mainc, c.combc, c.style)
+		if c.width == 2 {
+			n++
+		}
 	}
 	return lX, lN
 }
@@ -245,6 +249,9 @@ func (root *Root) drawNoWrapLine(y int, lX int, lN int, lineC LineC) (int, int)
 		}
 		c := lineC.lc[lX+n]
 		screen.SetContent(x, y, c.mainc, c.combc, c.style)
+		if c.width == 2 {
+			n++
+		}
 	}
 	lN++
 	return lX, lN
@@ -267,22 +274,28 @@ func (root *Root) drawVerticalHeader(y int, wrapNum int, lineC LineC) {
 	}
 
 	screen := root.Screen
-	for n := range widthVH {
+	x := root.scr.startX
+	for n := 0; n < widthVH; n++ {
 		c := DefaultContent
 		if n < len(lineC.lc) {
 			c = lineC.lc[n]
 		}
-		style := applyStyle(c.style, root.Doc.Style.VerticalHeader)
 		if n == widthVH-2 && c.width == 2 {
-			style = applyStyle(defaultStyle, root.Doc.Style.VerticalHeaderBorder)
-			screen.SetContent(root.scr.startX+n, y, c.mainc, c.combc, style)
+			style := applyStyle(defaultStyle, root.Doc.Style.VerticalHeaderBorder)
+			screen.SetContent(x, y, c.mainc, c.combc, style)
 			return
 		} else if n == widthVH-1 {
-			style = applyStyle(defaultStyle, root.Doc.Style.VerticalHeaderBorder)
-			screen.SetContent(root.scr.startX+n, y, c.mainc, c.combc, style)
+			style := applyStyle(defaultStyle, root.Doc.Style.VerticalHeaderBorder)
+			screen.SetContent(x, y, c.mainc, c.combc, style)
 			return
 		}
-		screen.SetContent(root.scr.startX+n, y, c.mainc, c.combc, style)
+		style := applyStyle(c.style, root.Doc.Style.VerticalHeader)
+		screen.SetContent(x, y, c.mainc, c.combc, style)
+		x++
+		if c.width == 2 {
+			x++
+			n++
+		}
 	}
 }
 
@@ -351,13 +364,33 @@ func (root *Root) drawLineNumber(lN int, y int, valid bool) {
 	root.Screen.SetContent(len(numC), y, ' ', nil, defaultStyle)
 }
 
+// drawTitle sets the terminal title if TerminalTitle is enabled.
+func (root *Root) drawTitle() {
+	if root.Config.SetTerminalTitle {
+		root.Screen.SetTitle(root.displayTitle())
+	}
+}
+
+// displayTitle returns the caption string of the document.
+func (root *Root) displayTitle() string {
+	if root.Doc.Caption != "" {
+		return root.Doc.Caption
+	}
+	return root.Doc.FileName
+}
+
 // setContentString is a helper function that draws a string with setContent.
 func (root *Root) setContentString(vx int, vy int, lc contents) {
 	screen := root.Screen
-	for x, content := range lc {
-		screen.SetContent(vx+x, vy, content.mainc, content.combc, content.style)
+	x := vx
+	for _, content := range lc {
+		screen.SetContent(x, vy, content.mainc, content.combc, content.style)
+		x++
+		if content.width == 2 {
+			x++
+		}
 	}
-	screen.SetContent(vx+len(lc), vy, 0, nil, defaultStyle.Normal())
+	screen.SetContent(x, vy, 0, nil, defaultStyle.Normal())
 }
 
 // clearEOL clears from the specified position to the right end.
@@ -380,6 +413,9 @@ func (root *Root) coordinatesStyle(lN int, y int) {
 	if root.Doc.jumpTargetHeight != 0 && root.Doc.headerHeight+root.Doc.jumpTargetHeight == y {
 		root.applyStyleToLine(y, root.Doc.Style.JumpTargetLine)
 	}
+	if root.Doc.pauseFollow && lN == root.Doc.pauseLastNum {
+		root.applyStyleToLine(y, root.Doc.Style.PauseLine)
+	}
 }
 
 // applyStyleToAlternate applies from beginning to end of line.
@@ -444,7 +480,7 @@ func (root *Root) hideOtherSection(y int, line LineC) {
 // drawSelect highlights the selection.
 // Multi-line selection is included until the end of the line,
 // but if the rectangle flag is true, the rectangle will be the range.
-func (root *Root) drawSelect(x1, y1, x2, y2 int, sel bool) {
+func (root *Root) drawSelect(x1, y1, x2, y2 int, sel MouseSelectState) {
 	if y2 < y1 {
 		y1, y2 = y2, y1
 		x1, x2 = x2, x1
@@ -453,40 +489,69 @@ func (root *Root) drawSelect(x1, y1, x2, y2 int, sel bool) {
 		if x2 < x1 {
 			x1, x2 = x2, x1
 		}
-		root.reverseRange(y1, x1, x2+1, sel)
+		root.applySelectionRange(y1, x1, x2+1, sel)
 		return
 	}
 	if root.scr.mouseRectangle {
 		for y := y1; y <= y2; y++ {
-			root.reverseRange(y, x1, x2+1, sel)
+			root.applySelectionRange(y, x1, x2+1, sel)
 		}
 		return
 	}
 
-	root.reverseRange(y1, x1, root.scr.vWidth, sel)
+	root.applySelectionRange(y1, x1, root.scr.vWidth, sel)
 	for y := y1 + 1; y < y2; y++ {
-		root.reverseRange(y, 0, root.scr.vWidth, sel)
+		root.applySelectionRange(y, 0, root.scr.vWidth, sel)
 	}
-	root.reverseRange(y2, 0, x2+1, sel)
+	root.applySelectionRange(y2, 0, x2+1, sel)
 }
 
-// reverseRange reverses the specified range.
-func (root *Root) reverseRange(y int, start int, end int, sel bool) {
+// applySelectionRange applies selection style to the specified range.
+func (root *Root) applySelectionRange(y int, start int, end int, selectState MouseSelectState) {
 	if start >= end {
 		return
 	}
+
+	var selectStyle OVStyle
+	switch selectState {
+	case SelectActive:
+		selectStyle = root.Doc.Style.SelectActive
+	case SelectCopied:
+		selectStyle = root.Doc.Style.SelectCopied
+	default:
+		return // No selection style to apply
+	}
+
 	for x := start; x < end; x++ {
 		mainc, combc, style, width := root.Screen.GetContent(x, y)
-		style = style.Reverse(sel)
-		root.Screen.SetContent(x, y, mainc, combc, style)
+		newStyle := applyStyle(style, selectStyle)
+		root.Screen.SetContent(x, y, mainc, combc, newStyle)
 		if width == 2 {
 			x++
 		}
 	}
 }
 
+// quitCheck checks if it should quit when the document is small.
+func (root *Root) quitCheck() bool {
+	if !root.Config.QuitSmall {
+		return false
+	}
+	if !root.docSmall() {
+		return false
+	}
+	if root.DocumentLen() == 1 && !root.Config.QuitSmallFilter {
+		root.Config.IsWriteOnExit = true
+		return true
+	}
+	return false
+}
+
 // notifyEOFReached notifies that EOF has been reached.
 func (root *Root) notifyEOFReached(m *Document) {
+	if root.Config.NotifyEOF == 0 {
+		return
+	}
 	root.setMessagef("EOF reached %s", m.FileName)
 	root.notify(root.Config.NotifyEOF)
 }
