@@ -17,18 +17,18 @@ const (
 	filter
 )
 
-// setForwardSearchMode sets the inputMode to Forwardsearch.
-func (root *Root) setForwardSearchMode(context.Context) {
+// inputForwardSearch sets the inputMode to Forwardsearch.
+func (root *Root) inputForwardSearch(context.Context) {
 	root.setSearchMode(forward)
 }
 
-// setBackSearchMode sets the inputMode to Backsearch.
-func (root *Root) setBackSearchMode(context.Context) {
+// inputBackSearch sets the inputMode to Backsearch.
+func (root *Root) inputBackSearch(context.Context) {
 	root.setSearchMode(backward)
 }
 
-// setSearchFilterMode sets the inputMode to Filter.
-func (root *Root) setSearchFilterMode(context.Context) {
+// inputSearchFilter sets the inputMode to Filter.
+func (root *Root) inputSearchFilter(context.Context) {
 	root.setSearchMode(filter)
 }
 
@@ -36,10 +36,10 @@ func (root *Root) setSearchFilterMode(context.Context) {
 func (root *Root) setSearchMode(searchType searchType) {
 	input := root.input
 	input.reset()
-	input.Event = newSearchEvent(input.SearchCandidate, searchType)
+	input.Event = newSearchEvent(input.Candidate[Search], searchType)
 
 	if root.searcher != nil {
-		input.SearchCandidate.toLast(root.searcher.String())
+		input.Candidate[Search].toLast(root.searcher.String())
 	}
 
 	root.Doc.nonMatch = false // Reset nonMatch.
@@ -82,7 +82,7 @@ type eventInputSearch struct {
 	searchType searchType
 }
 
-// newSearchEvent returns SearchInput.
+// newSearchEvent returns a new eventInputSearch.
 func newSearchEvent(clist *candidate, searchType searchType) *eventInputSearch {
 	return &eventInputSearch{
 		value:      "",
@@ -120,7 +120,7 @@ func (e *eventInputSearch) Prompt() string {
 
 // Confirm returns the event when the input is confirmed.
 func (e *eventInputSearch) Confirm(str string) tcell.Event {
-	e.value = str
+	e.value = stripBackSlash(str)
 	e.clist.toLast(str)
 	e.SetEventNow()
 	return e
@@ -140,10 +140,24 @@ func (e *eventInputSearch) Down(str string) string {
 
 // searchCandidates returns the list of search candidates.
 func (input *Input) searchCandidates(n int) []string {
-	input.SearchCandidate.mux.Lock()
-	defer input.SearchCandidate.mux.Unlock()
+	input.Candidate[Search].mux.Lock()
+	defer input.Candidate[Search].mux.Unlock()
 
-	listLen := len(input.SearchCandidate.list)
+	listLen := len(input.Candidate[Search].list)
 	start := max(0, listLen-n)
-	return input.SearchCandidate.list[start:listLen]
+	return input.Candidate[Search].list[start:listLen]
+}
+
+// stripBackSlash removes the backslash from the string
+// when the backslash is followed by an exclamation mark.
+func stripBackSlash(str string) string {
+	if len(str) < 2 {
+		return str
+	}
+	idx := strings.Index(str, "\\!")
+	if idx < 0 {
+		return str
+	}
+	str = str[:idx] + str[idx+1:]
+	return str
 }
